@@ -32,7 +32,7 @@
 /**
  * GtkAdjustment:
  *
- * `GtkAdjustment` is a model for a numeric value.
+ * A model for a numeric value.
  *
  * The `GtkAdjustment` has an associated lower and upper bound.
  * It also contains step and page increments, and a page size.
@@ -207,7 +207,7 @@ gtk_adjustment_class_init (GtkAdjustmentClass *class)
 
   /**
    * GtkAdjustment::changed:
-   * @adjustment: the object which received the signal
+   * @adjustment: the adjustment which emitted the signal
    *
    * Emitted when one or more of the `GtkAdjustment` properties have been
    * changed.
@@ -226,7 +226,7 @@ gtk_adjustment_class_init (GtkAdjustmentClass *class)
 
   /**
    * GtkAdjustment::value-changed:
-   * @adjustment: the object which received the signal
+   * @adjustment: the adjustment which emitted the signal
    *
    * Emitted when the value has been changed.
    */
@@ -352,19 +352,23 @@ gtk_adjustment_dispatch_properties_changed (GObject     *object,
     }
 }
 
+double
+gtk_adjustment_get_bounded_upper (GtkAdjustment *self)
+{
+  GtkAdjustmentPrivate *priv = gtk_adjustment_get_instance_private (self);
+
+  /* The real upper value is upper - page_size and not below the lower value. */
+  return MAX (priv->lower, priv->upper - priv->page_size);
+}
+
 static double
 gtk_adjustment_sanitize_value (GtkAdjustment *self,
                                double         value)
 {
   GtkAdjustmentPrivate *priv = gtk_adjustment_get_instance_private (self);
+  gdouble upper = gtk_adjustment_get_bounded_upper (self);
 
-  /* don't use CLAMP() so we don't end up below lower if upper - page_size
-   * is smaller than lower
-   */
-  value = MIN (value, priv->upper - priv->page_size);
-  value = MAX (value, priv->lower);
-
-  return value;
+  return CLAMP (value, priv->lower, upper);
 }
 
 /**
@@ -400,11 +404,11 @@ gtk_adjustment_new (double value,
 
 /**
  * gtk_adjustment_get_value:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  *
  * Gets the current value of the adjustment.
  *
- * Returns: The current value of the adjustment
+ * Returns: the current value
  */
 double
 gtk_adjustment_get_value (GtkAdjustment *adjustment)
@@ -536,7 +540,7 @@ gtk_adjustment_set_value_internal (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_set_value:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @value: the new value
  *
  * Sets the `GtkAdjustment` value.
@@ -554,6 +558,7 @@ gtk_adjustment_set_value (GtkAdjustment *adjustment,
 			  double         value)
 {
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (value));
 
   gtk_adjustment_set_value_internal (adjustment, value, FALSE);
 }
@@ -563,17 +568,18 @@ gtk_adjustment_animate_to_value (GtkAdjustment *adjustment,
 			         double         value)
 {
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (value));
 
   gtk_adjustment_set_value_internal (adjustment, value, TRUE);
 }
 
 /**
  * gtk_adjustment_get_lower:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  *
  * Retrieves the minimum value of the adjustment.
  *
- * Returns: The current minimum value of the adjustment
+ * Returns: the minimum value
  **/
 double
 gtk_adjustment_get_lower (GtkAdjustment *adjustment)
@@ -587,7 +593,7 @@ gtk_adjustment_get_lower (GtkAdjustment *adjustment)
 
 /**
  * gtk_adjustment_set_lower:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @lower: the new minimum value
  *
  * Sets the minimum value of the adjustment.
@@ -611,6 +617,7 @@ gtk_adjustment_set_lower (GtkAdjustment *adjustment,
   GtkAdjustmentPrivate *priv = gtk_adjustment_get_instance_private (adjustment);
 
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (lower));
 
   if (lower != priv->lower)
     {
@@ -621,11 +628,11 @@ gtk_adjustment_set_lower (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_get_upper:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  *
  * Retrieves the maximum value of the adjustment.
  *
- * Returns: The current maximum value of the adjustment
+ * Returns: the maximum value
  */
 double
 gtk_adjustment_get_upper (GtkAdjustment *adjustment)
@@ -639,7 +646,7 @@ gtk_adjustment_get_upper (GtkAdjustment *adjustment)
 
 /**
  * gtk_adjustment_set_upper:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @upper: the new maximum value
  *
  * Sets the maximum value of the adjustment.
@@ -658,6 +665,7 @@ gtk_adjustment_set_upper (GtkAdjustment *adjustment,
   GtkAdjustmentPrivate *priv = gtk_adjustment_get_instance_private (adjustment);
 
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (upper));
 
   if (upper != priv->upper)
     {
@@ -668,11 +676,11 @@ gtk_adjustment_set_upper (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_get_step_increment:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  *
  * Retrieves the step increment of the adjustment.
  *
- * Returns: The current step increment of the adjustment.
+ * Returns: the step increment
  */
 double
 gtk_adjustment_get_step_increment (GtkAdjustment *adjustment)
@@ -686,7 +694,7 @@ gtk_adjustment_get_step_increment (GtkAdjustment *adjustment)
 
 /**
  * gtk_adjustment_set_step_increment:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @step_increment: the new step increment
  *
  * Sets the step increment of the adjustment.
@@ -702,6 +710,7 @@ gtk_adjustment_set_step_increment (GtkAdjustment *adjustment,
   GtkAdjustmentPrivate *priv = gtk_adjustment_get_instance_private (adjustment);
 
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (step_increment));
 
   if (step_increment != priv->step_increment)
     {
@@ -712,11 +721,11 @@ gtk_adjustment_set_step_increment (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_get_page_increment:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  *
  * Retrieves the page increment of the adjustment.
  *
- * Returns: The current page increment of the adjustment
+ * Returns: the page increment
  **/
 double
 gtk_adjustment_get_page_increment (GtkAdjustment *adjustment)
@@ -730,7 +739,7 @@ gtk_adjustment_get_page_increment (GtkAdjustment *adjustment)
 
 /**
  * gtk_adjustment_set_page_increment:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @page_increment: the new page increment
  *
  * Sets the page increment of the adjustment.
@@ -746,6 +755,7 @@ gtk_adjustment_set_page_increment (GtkAdjustment *adjustment,
   GtkAdjustmentPrivate *priv = gtk_adjustment_get_instance_private (adjustment);
 
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (page_increment));
 
   if (page_increment != priv->page_increment)
     {
@@ -756,11 +766,11 @@ gtk_adjustment_set_page_increment (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_get_page_size:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  *
  * Retrieves the page size of the adjustment.
  *
- * Returns: The current page size of the adjustment
+ * Returns: the page size
  **/
 double
 gtk_adjustment_get_page_size (GtkAdjustment *adjustment)
@@ -774,7 +784,7 @@ gtk_adjustment_get_page_size (GtkAdjustment *adjustment)
 
 /**
  * gtk_adjustment_set_page_size:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @page_size: the new page size
  *
  * Sets the page size of the adjustment.
@@ -790,6 +800,7 @@ gtk_adjustment_set_page_size (GtkAdjustment *adjustment,
   GtkAdjustmentPrivate *priv = gtk_adjustment_get_instance_private (adjustment);
 
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (page_size));
 
   if (page_size != priv->page_size)
     {
@@ -800,7 +811,7 @@ gtk_adjustment_set_page_size (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_configure:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @value: the new value
  * @lower: the new minimum value
  * @upper: the new maximum value
@@ -858,12 +869,12 @@ gtk_adjustment_configure (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_clamp_page:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  * @lower: the lower value
  * @upper: the upper value
  *
- * Updates the value property to ensure that the range
- * between @lower and @upper is in the current page.
+ * Updates the value of the adjustment to ensure that the
+ * given range is contained in the current page.
  *
  * The current page goes from `value` to `value` + `page-size`.
  * If the range is larger than the page size, then only the
@@ -881,6 +892,7 @@ gtk_adjustment_clamp_page (GtkAdjustment *adjustment,
   gboolean need_emission;
 
   g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+  g_return_if_fail (isfinite (lower) && isfinite (upper));
 
   lower = CLAMP (lower, priv->lower, priv->upper);
   upper = CLAMP (upper, priv->lower, priv->upper);
@@ -904,11 +916,11 @@ gtk_adjustment_clamp_page (GtkAdjustment *adjustment,
 
 /**
  * gtk_adjustment_get_minimum_increment:
- * @adjustment: a `GtkAdjustment`
+ * @adjustment: an adjustment
  *
  * Gets the smaller of step increment and page increment.
  *
- * Returns: the minimum increment of @adjustment
+ * Returns: the minimum increment
  */
 double
 gtk_adjustment_get_minimum_increment (GtkAdjustment *adjustment)
